@@ -28,7 +28,7 @@
 #'              main ="Spatial Distribution by Lights for Sao Paulo - Brazil")
 #'}
 #'
-#'@source Data avaliable \url{https://www.ospo.noaa.gov/Operations/DMSP/index.html}
+#'@source Data avaliable \url{https://www.nesdis.noaa.gov/current-satellite-missions/currently-flying/defense-meteorological-satellite-program}
 #'@details About the DMSP and example data \url{https://en.wikipedia.org/wiki/Defense_Meteorological_Satellite_Program}
 
 areaSource <- function(s,r,grid = NA,name = "",as_frac=FALSE,verbose = TRUE){
@@ -37,41 +37,19 @@ areaSource <- function(s,r,grid = NA,name = "",as_frac=FALSE,verbose = TRUE){
     cat(paste("processing ",name,"area ... \n",sep = ""))
   }
 
-  # sp <- suppressWarnings( raster::mask(r,sp::spTransform(s,sp::CRS(sp::proj4string(r)))) )
   sp <- suppressWarnings( raster::mask(r,sf::st_transform(sf::st_as_sf(s),crs = raster::crs(r,asText=TRUE))))
 
   if(!is.na(grid[1])){
-    if(grid$map_proj == 1){
-      dx    <- grid$DX*1000  # using meters
-      dy    <- grid$DX*1000
-      ncols <- grid$Horizontal[1]
-      nrows <- grid$Horizontal[2]
-
-      # projcoords <- rgdal::project(grid$coords,grid$geogrd.proj)
-      pontos     <- sf::st_multipoint(x = grid$coords, dim = "XY")
-      coords     <- sf::st_sfc(x = pontos, crs = "+proj=longlat")
-      transform  <- sf::st_transform(x = coords, crs = grid$geogrd.proj)
-      projcoords <- sf::st_coordinates(transform)[,1:2]
-
-      xmn <- projcoords[1,1] - dx/2.0  # Left border
-      ymx <- projcoords[1,2] + dy/2.0  # upper border
-      xmx <- xmn + ncols*dx            # Right border
-      ymn <- ymx - nrows*dy            # Bottom border
-      # Create a raster
-      box <- suppressWarnings(
-        raster::raster(resolution = dx,
-                       xmn = xmn,
-                       xmx = xmx,
-                       ymn = ymn,
-                       ymx = ymx,
-                       crs = grid$geogrd.proj))
+    if(grid$map_proj %in% c(1,2,3,6)){
+      box   <- grid$r
     }else{
       col   <- grid$Horizontal[1]
       rol   <- grid$Horizontal[2]
       r.lat <- range(grid$Lat)
       r.lon <- range(grid$Lon)
       box   <- raster::raster(nrows=rol,ncols=col,
-                              xmn=r.lon[1],xmx=r.lon[2],ymn=r.lat[1],ymx=r.lat[2],
+                              xmn=r.lon[1],xmx=r.lon[2],
+                              ymn=r.lat[1],ymx=r.lat[2],
                               crs='+proj=longlat')
     }
 
